IC_TP_CUSTOM_DEFINED_TARG_POP_MST_ID = 1
IC_TP_TOTAL_POPULATION_MST_ID = 2
IC_TP_FEMALES_REPROD_AGE_15_TO_49_MST_ID = 3
IC_TP_FEMALES_REPROD_AGE_IN_UNION_MST_ID = 4
IC_TP_PREGNANT_FEMALES_MST_ID = 5
IC_TP_LIVE_BIRTHS_MST_ID = 6
IC_TP_POP_UNDER_1_MST_ID = 7
IC_TP_ABORTIONS_MST_ID = 8
IC_MstFPUsers = 9
IC_TP_POP_1_TO_59_MONTHS_MST_ID = 10
IC_TP_POP_6_TO_59_MONTHS_MST_ID = 11
IC_TP_FEMALES_11_MST_ID = 12
IC_MstNumHouseholds = 13
IC_TP_POP_15_PLUS_MST_ID = 14
IC_TP_MALES_15_TO_49_MST_ID = 20
IC_TP_MALES_15_PLUS_MST_ID = 21
IC_TP_FEMALES_15_PLUS_MST_ID = 22
IC_TP_POP_15_TO_49_MST_ID = 23
IC_TP_POP_15_PLUS_NEED_ART_MST_ID = 25
IC_TP_NUM_CHILDREN_REC_ART_MST_ID = 29
IC_TP_NUM_CHILDREN_NEED_COTRIM_MST_ID = 30
IC_TP_NUM_CHILDREN_REC_COTRIM_MST_ID = 31
IC_TP_NUM_ADULTS_REC_ART_MST_ID = 33
IC_TP_POP_6_TO_23_MONTHS_MST_ID = 34
IC_TP_HIV_POS_POP_MST_ID = 35
IC_TP_POP_0_TO_23_MONTHS_MST_ID = 36
IC_TP_HIV_POS_CHILDREN_MST_ID = 37
IC_TP_HIV_POS_FEMALES_BREASTFEEDING_MST_ID = 38
IC_TP_POP_NEED_IO_MGMT_MST_ID = 39
IC_TP_NUM_POP_REC_ART_MST_ID = 40
IC_TP_POP_INIT_ART_1ST_6_MONTHS_MST_ID = 41
IC_TP_POP_6_TO_14_MST_ID = 42
IC_TP_YOUTH_SCHOOL_AGE_5_TO_15_MST_ID = 43
IC_TP_FEMALES_25_TO_65_MST_ID = 44
IC_TP_FEMALES_40_TO_65_MST_ID = 45
IC_TP_FEMALES_NEED_PMTCT_MST_ID = 46
IC_MstAdultMSM = 47
IC_MstFemaleSexWorkers = 48
IC_TP_POP_12_TO_17_MST_ID = 49
IC_MstInjectDrugUsers = 50
IC_TP_POP_HIV_POS_MST_ID = 51
IC_MstNumNewTBCasesExclRel = 52
IC_TP_POP_LOW_RISK_CVD_MST_ID = 53
IC_TP_POP_40_PLUS_MST_ID = 54
IC_TP_POP_5_TO_19_MST_ID = 55
IC_TP_POP_20_PLUS_MST_ID = 56
IC_TP_FEMALES_30_PLUS_MST_ID = 57
IC_TP_ALL_FEMALES_MST_ID = 58
IC_TP_AGE_GROUP_SET_1_MST_ID = 59
IC_TP_AGE_GROUP_SET_2_MST_ID = 60
IC_TP_FEMALES_25_TO_70_MST_ID = 61
IC_TP_FEMALES_40_TO_70_MST_ID = 62
IC_TP_FEMALES_BREAST_CANCER_MST_ID = 63
IC_TP_POP_0_TO_59_MONTHS_MST_ID = 64
IC_TP_DIRECT_ENTRY_MST_ID = 65
IC_MstFemalesRecBrstCncrTrtmnt = 66
IC_TP_POP_15_PLUS_LIVING_WITH_HIV_M_MST_ID = 67
IC_TP_POP_15_PLUS_LIVING_WITH_HIV_F_MST_ID = 68
IC_TP_POP_2_TO_12_MST_ID = 69
IC_TP_POP_12_TO_59_MONTHS_MST_ID = 70
IC_MstMaleSexWorkers = 71
IC_MstPopWithModSevDepression = 72
IC_MstPopWithPsychosis = 73
IC_MstPopWithEpilepsy = 74
IC_MstNumNewPulmTBCases = 79
IC_MstMDRAndXDRCases = 80
IC_TP_POP_0_TO_14_MST_ID = 92
IC_MstNumMalariaCases = 93
IC_MstPopWithMildDepression = 95
IC_MstPopWithADHD = 96
IC_MstPopWithConductDisorder = 97
IC_MstPopWithAlcohUseDisorder = 98
IC_MstPopWithBipolarDisorder = 99
IC_MstPopWithDepression = 100
IC_TP_INFANTS_SURV_PAST_1_MONTH_MST_ID = 101
IC_MstPopWithAnxiety = 102
IC_MstPopWithCOPD = 103
IC_MstPopWithAsthma = 104
IC_MstPopWithDiabetes = 105
IC_MstNumNewTBCases = 106
IC_MstNumNewPulmBactTBCases = 107
IC_MstNumNewPulmBactTBCasesPop = 108
IC_MstNumNewPulmBactTBCasesChildr = 109
IC_MstNumNewPulmBactHIVNegTBCases = 110
IC_MstNumNewPulmBactHIVNegTBCasesPop = 111
IC_MstNumNewPulmBactHIVNegTBCasesChildr = 112
IC_MstNumNewPulmBactHIVPosTBCases = 113
IC_MstNumNewPulmBactHIVPosTBCasesPop = 114
IC_MstNumNewPulmBactHIVPosTBCasesChildr = 115
IC_MstNumNewPulmClinTBCases = 116
IC_MstNumNewPulmClinHIVNegTBCases = 117
IC_MstNumNewPulmClinHIVPosTBCases = 118
IC_MstNumNewExPulmTBCases = 119
IC_MstNumNewExPulmHIVNegTBCases = 120
IC_MstNumNewExPulmHIVPosTBCases = 121
IC_MstNumRelTBCases = 122
IC_MstNumRelPulmTBCases = 123
IC_MstNumRelPulmBactTBCases = 124
IC_MstNumRelPulmBactHIVNegTBCases = 125
IC_MstNumRelPulmBactHIVPosTBCases = 126
IC_MstNumRelPulmClinTBCases = 127
IC_MstNumRelPulmClinHIVNegTBCases = 128
IC_MstNumRelPulmClinHIVPosTBCases = 129
IC_MstNumRelExPulmTBCases = 130
IC_MstNumRelExPulmHIVNegTBCases = 131
IC_MstNumRelExPulmHIVPosTBCases = 132
IC_MstNumNewTBCasesInclRel = 133
IC_MstNumNewNonMDR_TBCasesInclRel = 134
IC_MstNumNewNonMDR_TBCasesInclRelPop = 135
IC_MstNumNewNonMDR_TBCasesInclRelChildr = 136
IC_MstNumNewMDR_TBCasesInclRel = 137
IC_MstNumNewXDR_TBCasesInclRel = 138
IC_MstNumNewNonMDR_TBCasesExclRel = 139
IC_MstNumNewNonMDR_TBCasesExclRelPop = 140
IC_MstNumNewNonMDR_TBCasesExclRelChildr = 141
IC_MstNumNewMDR_TBCasesExclRel = 142
IC_MstNumNewXDR_TBCasesExclRel = 143
IC_MstNumPrTrTBCasesInclRel = 144
IC_MstNumPrTrNonMDR_TBCasesInclRel = 145
IC_MstNumPrTrNonMDR_TBCasesInclRelPop = 146
IC_MstNumPrTrNonMDR_TBCasesInclRelChildr = 147
IC_MstNumPrTrMDR_TBCasesInclRel = 148
IC_MstNumPrTrXDR_TBCasesInclRel = 149
IC_MstNumPrTrTBCasesExclRel = 150
IC_MstNumPrTrNonMDR_TBCasesExclRel = 151
IC_MstNumPrTrNonMDR_TBCasesExclRelPop = 152
IC_MstNumPrTrNonMDR_TBCasesExclRelChildr = 153
IC_MstNumPrTrMDR_TBCasesExclRel = 154
IC_MstNumPrTrXDR_TBCasesExclRel = 155
IC_MstNumNewRelTBCasesU15Yrs = 156
IC_MstNonXDRCases = 157
IC_MstXDRCases = 158
IC_MstNumTB_HIVCoInfCases = 159
IC_MstNumTB_HIVCoInfCasesNotOnART = 160
IC_MstNumTB_HIVCoInfCasesOnART = 161
IC_MstNumNewRelBactTBCases = 162
IC_MstNumNewRelPulmClinTBCases = 163
IC_MstNumNewRelExPulmTBCases = 164
IC_TP_NUM_FEMALES_30_TO_49_MST_ID = 165
IC_MstFemalesRecBreastCancerTreat = 166
IC_MstFemalesRecTreatPrecancLesCervCancer = 167
IC_MstFemalesPreCancerLesions = 168
IC_MstFemalesCervicalCancerDetS1 = 169
IC_MstFemalesCervicalCancerDetS2 = 170
IC_MstFemalesCervicalCancerDetS3 = 171
IC_MstFemalesCervicalCancerDetS4 = 172
IC_MstFemalesTreatCervCancerLast5Yrs = 173
IC_TP_POP_50_PLUS_MST_ID = 174
IC_MstPopRecColorectalCancerTreat = 175
IC_MstPopColorectalCancerDetS1 = 176
IC_MstPopColorectalCancerDetS2 = 177
IC_MstPopColorectalCancerDetS3 = 178
IC_MstPopColorectalCancerDetS4 = 179
IC_MstPopTreatColorectCancerLast5Yrs = 180
IC_MstFemalesBreastCancerDetS1 = 181
IC_MstFemalesBreastCancerDetS2 = 182
IC_MstFemalesBreastCancerDetS3 = 183
IC_MstFemalesBreastCancerDetS4 = 184
IC_MstFemalesDetectedBreastCancer = 185
IC_MstFemalesTreatBreastCancerLast5Yrs = 186
IC_TP_POP_10_TO_19_MST_ID = 187
IC_TP_FEMALES_10_TO_14_MST_ID = 188
IC_TP_FEMALES_15_TO_19_MST_ID = 189
IC_TP_POP_10_TO_49_MST_ID = 190
IC_TP_MALES_10_TO_49_MST_ID = 191
IC_TP_POP_10_PLUS_MST_ID = 192
IC_TP_POP_5_TO_14_MST_ID = 193
IC_TP_POP_1_TO_14_MST_ID = 194
IC_TP_POP_GT_6_MONTHS_MST_ID = 195
IC_TP_POP_3_TO_59_MONTHS_MST_ID = 196
IC_MstMalariaCases0t4 = 197
IC_MstMalariaCases5t14 = 198
IC_MstMalariaCases15Plus = 199
IC_MstMalariaCases5Plus = 200
IC_MstNumUncompMalariaCases = 201
IC_MstUncompMalariaCases0t4 = 202
IC_MstUncompMalariaCases5t14 = 203
IC_MstUncompMalariaCases15Plus = 204
IC_MstUncompMalariaCases5Plus = 205
IC_MstNumSevMalariaCases = 206
IC_MstSevMalariaCases0t4 = 207
IC_MstSevMalariaCases5t14 = 208
IC_MstSevMalariaCases15Plus = 209
IC_MstSevMalariaCases5Plus = 210
IC_TP_TOTAL_POP_EXCL_PREG_FEMALES_MST_ID = 211
IC_TP_PREGNANCIES_CARRIED_TO_TERM_MST_ID = 212
IC_MstPop6t23moFoodSec = 213
IC_MstPop6t23moFoodInsec = 214
IC_MstPopSBP_GT160_CVD_Risk_LT30 = 215
IC_MstPopSBP_GT140_CVD_Risk_LT30 = 216
IC_MstPopSBP_GT160_CVD_Risk_LT20 = 217
IC_MstPopSBP_GT140_CVD_Risk_LT20 = 218
IC_MstPopCholGT8_CVD_Risk_LT30 = 219
IC_MstPopCholGT6_CVD_Risk_LT30 = 220
IC_MstPopCholGT8_CVD_Risk_LT20 = 221
IC_MstPopCholGT6_CVD_Risk_LT20 = 222
IC_MstPopCVD_DiabRisk20t30 = 223
IC_MstPopCVD_DiabRiskGT30 = 224
IC_MstPopStroke_A_IHD_A = 225
IC_MstPopIHD_PA = 226
IC_MstPopStroke_PA_StrokeIHD_PA = 227
IC_MstPopStrokeIHD_A_PA_5Combo = 228
IC_TP_POP_1_TO_4_MST_ID = 229
IC_MstSputumSmearMicr_DAT = 230
IC_MstGeneXpert_DAT = 231
IC_MstChestXRay_DAT = 232
IC_MstCultTests_DAT = 233
IC_MstNumScreenedThroughPathway_DAT = 234
IC_MstActiveCaseFindingHHs = 235
IC_MstActiveCaseFindingHRGs = 236
IC_MstNumHHContEval = 237
IC_MstNumPersHRGsEval = 238
IC_MstNumNewARTPatEval = 239
IC_MstNumExistARTPatEval = 240
IC_MstTBNegNewAdultARTPat = 241
IC_MstTBNegExistAdultARTPat = 242
IC_MstTBNegNewChildARTPat = 243
IC_MstTBNegExistChildARTPat = 244
IC_MstAdultHHContacts = 245
IC_MstChildHHContacts = 246
IC_MstAdultHRGs = 247
IC_MstPopHRGs = 248
IC_MstNumChildHHContTestedLTBI = 249
IC_MstNumAdultHHContTestedLTBI = 250
IC_MstNumChildHRGsTestedLTBI = 251
IC_MstNumAdultHRGsTestedLTBI = 252
IC_MstNumNewChildARTPatTestedLTBI = 253
IC_MstNumNewAdultARTPatTestedLTBI = 254
IC_MstNumExistChildARTPatTestedLTBI = 255
IC_MstNumExistAdultARTPatTestedLTBI = 256
IC_MstPopNumToScreenActiveTBAllAges = 257
IC_MstPopNumToScreenActiveTBChildren = 258
IC_MstPopNumToScreenActiveTBAdults = 259
IC_MstPopNumScreenedActiveTBAllAges = 260
IC_MstPopNumScreenedActiveTBChildren = 261
IC_MstPopNumScreenedActiveTBAdults = 262
IC_MstPopNumLinkedActiveTBAllAges = 263
IC_MstPopNumLinkedActiveTBChildren = 264
IC_MstPopNumLinkedActiveTBAdults = 265
IC_TP_FEMALES_15_TO_24_MST_ID = 266
IC_TP_POP_15_TO_24_MST_ID = 267
IC_TP_HH_CONTACTS_PULM_TB_0_TO_14_ELIG_SCR_MST_ID = 268
IC_TP_HH_CONTACTS_PULM_TB_0_TO_4_ELIG_SCR_MST_ID = 269
IC_TP_HH_CONTACTS_PULM_TB_5_TO_14_ELIG_SCR_MST_ID = 270
IC_TP_HH_CONTACTS_PULM_15_PLUS_ELIG_SCR_MST_ID = 271
IC_TP_PRISONERS_PULM_15_PLUS_ELIG_SCR_MST_ID = 272
IC_TP_MINERS_SILICA_PULM_TB_15_PLUS_ELIG_SCR_MST_ID = 273
IC_TP_POP_UNTR_FIBR_LESIONS_PULM_TB_15_PLUS_ELIG_SCR_MST_ID = 274
IC_TP_POP_RISK_FACTORS_GT_PT_1_PREV_PULM_15_PLUS_ELIG_SCR_MST_ID = 275
IC_TP_POP_RISK_FACTORS_LIMIT_HLTH_CARE_PULM_15_PLUS_ELIG_SCR_MST_ID = 276
IC_TP_POP_GT_PT_5_PERC_PREV_PULM_TB_15_PLUS_ELIG_SCR_MST_ID = 277
IC_TP_HH_CONTACTS_PULM_TB_5_TO_14_ELIG_EVAL_MST_ID = 278
IC_TP_HH_CONTACTS_PULM_15_PLUS_ELIG_EVAL_MST_ID = 279
IC_TP_HH_CONTACTS_PULM_TB_0_TO_4_TESTED_TB_MST_ID = 280
IC_TP_PLHIV_PULM_TB_ART_NOT_SERIOUS_10_PLUS_ELIG_SCR_MST_ID = 281
IC_TP_PULM_TB_HIV_POS_NOT_ON_ART_10_PLUS_ELIG_SCR_MST_ID = 282
IC_TP_PLHIV_PULM_TB_ART_SERIOUS_10_PLUS_ELIG_SCR_MST_ID = 283
IC_TP_CLHIV_PULM_TB_ON_ART_NOT_SERIOUS_0_TO_9_ELIG_SCR_MST_ID = 284
IC_TP_PREV_TB_INFECT_15_PLUS_DRUG_SUSC_STRAINS_MST_ID = 285
IC_TP_PREV_TB_INFECT_0_TO_14_DRUG_SUSC_STRAINS_MST_ID = 286
IC_TP_PREV_TB_INFECT_DRUG_RESIST_STRAINS_MST_ID = 288
IC_TP_PULM_TB_HIV_NEG_15_PLUS_CLIN_ASSESSED_MST_ID = 289
IC_TP_PULM_TB_HIV_NEG_0_TO_14_CLIN_ASSESSED_MST_ID = 290
IC_TP_EXTRAPULM_TB_HIV_NEG_15_PLUS_CLIN_ASSESSED_MST_ID = 291
IC_TP_EXTRAPULM_TB_HIV_NEG_0_TO_14_PLUS_CLIN_ASSESSED_MST_ID = 292
IC_TP_PULM_TB_15_PLUS_REF_DIAG_EVAL_MST_ID = 293
IC_TP_EXTRAPULM_TB_15_PLUS_REF_DIAG_EVAL_MST_ID = 294
IC_TP_PULM_TB_0_TO_14_REF_DIAG_EVAL_MST_ID = 295
IC_TP_EXTRAPULM_TB_0_TO_14_REF_DIAG_EVAL_MST_ID = 296
IC_TP_HRGS_PULM_TB_15_PLUS_REF_DIAG_EVAL_MST_ID = 297
IC_TP_HH_CONTACTS_PULM_TB_0_TO_14_REF_DIAG_EVAL_MST_ID = 298
IC_TP_PLHIV_PULM_TB_ON_ART_NOT_SERIOUS_ILL_15_PLUS_REF_DIAG_EVAL_MST_ID = 299
IC_TP_PLHIV_PULM_TB_ON_ART_SERIOUS_ILL_15_PLUS_REF_DIAG_EVAL_MST_ID = 300
IC_TP_PLHIV_PULM_TB_ON_ART_NOT_SERIOUS_ILL_0_TO_14_PLUS_REF_DIAG_EVAL_MST_ID = 301
IC_TP_PLHIV_PULM_TB_ON_ART_SERIOUS_ILL_0_TO_14_PLUS_REF_DIAG_EVAL_MST_ID = 302
IC_TP_PULM_TB_TO_BE_TESTED_RIFAMP_ISON_RESIST_MST_ID = 303
IC_TP_EXTRAPULM_TB_TO_BE_TESTED_RIFAMP_ISON_RESIST_MST_ID = 304
IC_TP_PULM_TB_TO_BE_TESTED_ISON_RESIST_RIFAMP_SENS_MST_ID = 305
IC_TP_EXTRAPULM_TB_TO_BE_TESTED_ISON_RESIST_RIFAMP_SENS_MST_ID = 306
IC_TP_PULM_TB_TO_BE_TESTED_FLUOR_RESIST_RIFAMP_RESIST_MST_ID = 307
IC_TP_TO_BE_TESTED_FLUOR_RESIST_RIFAMP_RESIST_MST_ID = 308
IC_TP_TO_BE_TESTED_BEDAQ_RESIST_RIFAMP_RESIST_MST_ID = 309
IC_TP_PULM_TB_TO_BE_TESTED_BEDAQ_RESIST_FLUOR_RESIST_MST_ID = 310
IC_TP_EXTRAPULM_TB_TO_BE_TESTED_BEDAQ_RESIST_FLUOR_RESIST_MST_ID = 311
IC_TP_TO_BE_TESTED_BEDAQ_RESIST_FLUOR_RESIST_MST_ID = 312
IC_TP_PULM_TB_TO_BE_TESTED_LINEZ_RESIST_RIFAMP_RESIST_MST_ID = 313
IC_TP_EXTRAPULM_TB_TO_BE_TESTED_LINEZ_RESIST_RIFAMP_RESIST_MST_ID = 314
IC_TP_TO_BE_TESTED_LINEZ_RESIST_RIFAMP_RESIST_MST_ID = 315
IC_TP_PULM_TB_TO_BE_TESTED_LINEZ_RESIST_FLUOR_RESIST_MST_ID = 316
IC_TP_EXTRAPULM_TB_TO_BE_TESTED_LINEZ_RESIST_FLUOR_RESIST_MST_ID = 317
IC_TP_TO_BE_TESTED_LINEZ_RESIST_FLUOR_RESIST_MST_ID = 318
IC_TP_TO_BE_TESTED_AMIK_RESIST_MST_ID = 319
IC_TP_TO_BE_TESTED_ETHIO_RESIST_MST_ID = 320
IC_TP_TO_BE_TESTED_PYRAZ_RESIST_MST_ID = 321
IC_TP_15_PLUS_NO_SEV_TB_RIFAMP_ISON_SENS_MST_ID = 322
IC_TP_0_14_PLUS_NO_SEV_TB_RIFAMP_ISON_SENS_MST_ID = 323
IC_TP_DRUG_SUSC_TB_15_PLUS_MENING_PERICARD_MST_ID = 324
IC_TP_DRUG_SUSC_TB_0_TO_14_PLUS_MENING_PERICARD_MST_ID = 325
IC_TP_15_PLUS_RIFAMP_SENS_ISON_RESIST_MST_ID = 326
IC_TP_0_TO_14_PLUS_RIFAMP_SENS_ISON_RESIST_MST_ID = 327
IC_TP_15_PLUS_RIFAMP_RESIST_FLUOR_SENS_MST_ID = 328
IC_TP_0_TO_14_PLUS_RIFAMP_RESIST_FLUOR_SENS_MST_ID = 329
IC_TP_15_PLUS_RIFAMP_RESIST_FLUOR_RESIST_PRE_XDR_MST_ID = 330
IC_TP_0_TO_14_PLUS_RIFAMP_RESIST_FLUOR_RESIST_PRE_XDR_MST_ID = 331
IC_TP_15_PLUS_PRE_XDR_RESIST_ONE_OF_MST_ID = 332
IC_TP_0_TO_14_PLUS_PRE_XDR_RESIST_ONE_OF_MST_ID = 333
IC_TP_PALL_CARE_TREAT_EXHASUTED_MST_ID = 334
IC_TP_TB_INFECT_PREV_0_TO_14_RECEIV_BCG_IMMUNIZ_MST_ID = 335
IC_TP_HIV_TB_COINFECTION_MST_ID = 336
IC_TP_HIV_TB_COINFECTION_CHILDREN_MST_ID = 337
IC_TP_NUM_TESTED_RESIST_BEDAQ_LINEZ_LEVO_MOXI_MST_ID = 338
IC_TP_TESTING_RIFAMP_RESIST_MST_ID = 339
IC_TP_TESTING_ISON_RESIST_RIFAMP_SENS_CASES_MST_ID = 340
IC_TP_POP_0_TO_11_MONTHS_MST_ID = 341
IC_TP_PROV_INIT_ALL_HRGS_NUM_ELIG_EVAL_TB_INF_MST_ID = 342
IC_TP_HH_CONTACTS_0_TO_4_ELIG_EVAL_MST_ID = 343
IC_TP_PAT_6_MO_ISON_RESIST_SHORTER_SEC_LINE_15_PLUS_MST_ID = 344
IC_TP_PAT_6_MO_ISON_RESIST_SHORTER_SEC_LINE_0_TO_14_MST_ID = 345
IC_TP_PAT_LONGER_REG_MDR_RR_TB_XDR_MST_ID = 346
IC_TP_PAT_6_MO_ISON_RESIST_SHORTER_SEC_LINE_MST_ID = 347
IC_TP_NUM_NEED_FIRST_LINE_TREAT_15_PLUS_MST_ID = 348
IC_TP_NUM_NEED_FIRST_LINE_TREAT_0_TO_14_MST_ID = 349
IC_TP_NUM_NEED_FIRST_LINE_TREAT_ALL_AGES_MST_ID = 350
IC_TP_NUM_NEED_SECOND_LINE_TREAT_0_TO_14_MST_ID = 351
IC_TP_NUM_NEED_SECOND_LINE_TREAT_15_PLUS_MST_ID = 352
IC_TP_NUM_REQ_LUNG_RESECT_SURGERY_15_PLUS_MST_ID = 353
IC_TP_NUM_REQ_LUNG_RESECT_SURGERY_0_TO_14_MST_ID = 354
IC_TP_PULM_EXTRAPULM_TB_ADULTS_15_P_PRES_RIFAMP_ISON_SENS_MST_ID = 355
IC_TP_PULM_EXTRAPULM_TB_CHILD_0_14_PRES_RIFAMP_ISON_SENS_MST_ID = 356
IC_TP_PULM_EXTRAPULM_TB_CHILD_0_14_NOT_SEV_PRES_RIFAMP_ISON_SENS_MST_ID = 357
IC_TP_HIV_POS_PREGNANT_WOMEN_MST_ID = 358
IC_TP_POP_0_TO_4_MST_ID = 359
IC_TP_NUM_REQ_LUNG_RESECT_SURGERY_MST_ID = 360
IC_TP_CLHIV_PULM_TB_ON_ART_INPAT_0_TO_9_ELIG_SCR_MST_ID = 361
IC_TP_15_PLUS_CLIN_ASSESSED_MST_ID = 362
IC_TP_0_TO_14_CLIN_ASSESSED_MST_ID = 363
IC_TP_NUM_NEED_SECOND_LINE_TREAT_ALL_AGES_MST_ID = 364



import numpy as np
from .alloc_parameters import alloc_parameters
from .make_model3 import make_model3

#from make_model import make_model
from .goveqs_scaleup import goveqs_scaleup
from .ode15s import ode15s, create_steps

from .InterventionScenario import InterventionScenario

from scipy import interpolate

def RunGlobalEpiModel(PARS,IntvnScn): #function [epi_outputs]=RunGlobalEpiModel(PARS,IntvnScn)

    epi_outputs=[] #epi_outputs=[];
    #%clear all; %load calibres2; xsto = xsto4;
    #%load calibres1; 

    xsto2 = PARS[0] #xsto2=PARS{1};
    outsto2 = PARS[1] #outsto2=PARS{2};

    xsto = xsto2 #xsto = xsto2;
    [M,I] = max(outsto2) #[M,I] = max(outsto2);

    xi = PARS[2] #xi=PARS{3};
    obj= PARS[3] #obj=PARS{4};

    i0 = PARS[4] #i0=PARS{5};
    s0 = PARS[5] #s0=PARS{6};
    gps0=PARS[6] #gps0=PARS{7};
    sel0=PARS[7] #sel0=PARS{8};
    agg0=PARS[8] #agg0=PARS{9};
    r = PARS[9] #r=PARS{10};
    p = PARS[10] #p=PARS{11};
    prm=PARS[11] #prm=PARS{12};


    #%load Model_setup;

    xs = xsto[I,:] #xs = xsto(I,:);  % Most probable parameter set 

    ix0 = 1e4 
    nx = 2 
    dx = round((np.size(xsto,1)-ix0)/nx) #ix0 = 1e4; nx = 2; dx = round((size(xsto,1)-ix0)/nx); %2e4 nx = 150
    xs_all = xsto[ix0::dx,:,0] #xs_all = xsto(ix0:dx:end,:,1);

    pct_xs= np.percenttile(xs_all,[2.5,50,97.5]) #pct_xs= prctile(xs_all,[2.5,50,97.5])


    #% % --- Get the Regional notifications
    tend1   = IntvnScn['year1'] #tend1   = IntvnScn.year1;%2024;  % Intervention starts except vaccination  
    tend1b  = IntvnScn['year2'] #tend1b  = IntvnScn.year2;%2028;  % Vaccination starts
    tend2   = IntvnScn['year3'] #tend2   = IntvnScn.year3;%2036;  % End date for simulation

    #% --- Do the simulations 
    opts = {'NonNegative': list(range(1, i0['nstates'] + 1)), 'rtol': 1e-10, 'atol': 1e-10, 'max_step': 1/64}#opts = odeset('NonNegative',[1:i0.nstates],'Refine',64,'AbsTol',1e-10,'RelTol',1e-10);


    r0 = r; p0 = p #;
    inct = [] #;
    noti = [] #;
    inch1= []
    mdr = []
    morth0= []
    morth1= []
    notimdr= []
    

    #% mk = round(size(xs,1)/25);
    #% for ii = 1:size(xs,1)
    #%     if mod(ii,mk) == 0; fprintf('%0.5g ',ii/mk); end 
    
    [r,p] = alloc_parameters(xs,prm['r'],prm['p'],xi) #;
    #% Get the initial conditions
    [out, aux] = obj(xs) #;
    init = aux['soln'][-1,:] #init = aux.soln(end,1:end);
    
    #% Extend initial condition for the full model with vaccine compartments  
    inds1 = np.intersect1d(s0['U'], s0['v0']) #inds1 = intersect(s0.U, s0.v0);
    inds2 = np.intersect1d([s0['Lf'], s0['Ls']], s0['v0']) #inds2 = intersect([s0.Lf, s0.Ls], s0.v0);
    inds3 = [s0['Isc'], s0['I'], s0['E'], s0['Rlo'], s0['Rhi'], s0['R']] #inds3 = [s0.Isc, s0.I, s0.E, s0.Rlo, s0.Rhi, s0.R];
    inds4 = [s0['Dx'],s0['Tx'],s0['Tx2']] #inds4 = [s0.Dx,s0.Tx,s0.Tx2];
    inds5 =   s0['Tx2'][-1] + np.array(range(0,8)) #inds5 =  s0.Tx2(end)+[1:9] #inds5 =  s0.Tx2(end)+[1:9];  % Auxiliary terms
    ind = [inds1, inds2, inds3,inds4,inds5] #ind = [inds1, inds2, inds3,inds4,inds5];
   
    #% To allocate results from a model without vaccine to input vector for full model with vaccine
    init0 = np.zeros[0,i0['nx']] #init0 = zeros(1,i0.nx);
    init0[ind] = init #init0(ind) = init;   

    tref = np.arrange(2022, tend2 + 1, 1) #tref = [2022:1:tend2];
     
    #% --- Now simulate without intervention (baseline)
    M0 = make_model3(p, r, i0, s0, gps0, prm)# M0 = make_model3(p, r, i0, s0, gps0, prm); 
    prm['growth'] = prm['gth'][2] #= prm.gth(3);
    #geq = @(t,in) goveqs_scaleup(t, in, M0, M0, [2022 2023], i0, prm, sel0, agg0);
    #[t0, soln0] = ode15s(geq, [2022 tend2], init0, odeset('NonNegative',[1:i0.nstates]));
    t0, soln0 = ode15s(goveqs_scaleup, init0, create_steps(2022, tend2, 1/12), args=(M0, M0, [2022, 2023],prm, sel0, p, agg0))

    soln  = soln0
    t     = t0
    #soln0 = interp1(t, soln, tref) #soln0 = interp1(t, soln, tref);
   
    soln0 = np.zeros((len(tref),np.shape(soln)[1]))
    for jj in range(np.shape(soln)[1]):#range(i['nx']):
        temp_fn_sol = interpolate.interp1d(t, soln[:,jj],fill_value="extrapolate") 
        soln0[:,jj] = [temp_fn_sol(ti) for ti in tref]


     
    #% Find the initial condition at the starting point for the interventions
    #geq = @(t,in) goveqs_scaleup(t, in, M0, M0, [2022 2023], i0, prm, sel0, agg0);
    #[ta, solna] = ode15s(geq, [2022 tend1], init0, odeset('NonNegative',[1:i0.nstates]));
    #initb = solna(end,:);
    ta, solna = ode15s(goveqs_scaleup, init0, create_steps(2022, tend1, 1/12), args=(M0, M0, [2022, 2023],prm, sel0, p, agg0))
    initb = solna[-1,:]
    
    #% --- Next simulate with interventions
    #%r1 = r; p1 = p;
    #%Set intervention to model parameters
    [p1,r1] = InterventionScenario(p,r,IntvnScn) #[p1,r1]=SetInterventionScenario(p,r,IntvnScn);
    
  
    #%     p1.pu  = p.pu + (1- p.pu)*0.35; 
    #%     p1.Dx(1) = 0.95;          % [0.95 0.95];  
    #%     
    #%     r1.cs(4)  = 1.2*r1.cs(4);       %choose specific age group
    #%     r1.cs2(4) = 1.2*r1.cs2(4);      %choose specific age group
    #%     r1.cs3(4) = 1.2*r1.cs(4);       %choose specific age group
    #%     
    #%     qq = 0.05;                                % Preventive therapy among household contacts independent of hiv status
    #%     r1.progression(4,:)  = r.progression(4,:)*(1-qq);    % Replace by this  --> p.PT_PLHIV = [1 1 (1-0.6)]
    #%     r1.reactivation(4,:) = r.reactivation(4,:)*(1-qq);
    #%     
    #%     p.PT_PLHIV = [1 1 (1-0.6)];                % PT among PLHIV reduces rate by 60%
    #%     
    #%     p1.MDR_rec = [0.5,0]; %0.7; %0.8;
    #%     r1.Tx2 = 9/12;                             % Shorter Tx2 regimn (9 months)
    #%     p1.cure2 = [0.7, 0]; %0.8; %0.9;
    #%     r1.default(1) = r.default(1)*(1-0.05);     % reduction of default rate(pu) (by inccreasing Tx completion and reducing LTFU)     
    #%  
    #%     r1.ART_init = xs(16)*(1+0.5);
    #%     
    
    M1 = make_model3(p1, r1, i0, s0, gps0, prm)
      
    #geq = @(t,in) goveqs_scaleup(t, in, M0, M1, tend1 + [0  3], i0, prm, sel0, agg0);
    #[tb, solnb] = ode15s(geq, [tend1 tend2], initb, opts);
    tb, solnb = ode15s(goveqs_scaleup, initb, create_steps(tend1, tend2, 1/12), args=(M0, M1, tend1 + np.array([0, 3]), i0, prm, sel0, agg0))
    initb = solnb[-1,:]
    
    soln  = np.concatenate([solna, solnb[1:,:]]) #soln  = [solna; solnb(2:end,:)];
    t     = np.concatenate([ta,    tb[1:]]) #t     = [ta;    tb(2:end)];
    soln8 = np.zeros((len(tref),np.shape(soln)[1])) #soln8 = interp1(t, soln, tref)#soln8 = interp1(t, soln, tref);
    for jj in range(np.shape(soln)[1]):#range(i['nx']):
        temp_fn_sol = interpolate.interp1d(t, soln[:,jj],fill_value="extrapolate") 
        soln8[:,jj] = [temp_fn_sol(ti) for ti in tref]

     
    #% --- Next simulate with vaccination
    #% Find vaccination starting point
    #[tv, solnv] = ode15s(geq, [tend1 tend1b], initb, opts);
    #initv = solnv(end,:);
    tv, solnv = ode15s(goveqs_scaleup, initb, create_steps(tend1, tend1b, 1/12), args=(M0, M1, tend1 + np.array([0, 3]), i0, prm, sel0, agg0))
    initv = solnv[-1,:]

    #% Choose suitable rate of vaccination and vaccine efficacy
    r2 = r1 
    p2 = p1
    p2['VE'] = np.array([0,  0.7]) #p2.VE = [0  0.7];       % Efficacy--> [infection prevention, disease prevention]
    r2['vacc'] = np.array([0, 0, 5, 5, 5]) #r2.vacc = [0 0 5 5 5];               % Vaccination rate (chosen)
    M2 = make_model3(p2, r2, i0, s0, gps0, prm) #M2 = make_model3(p2, r2, i0, s0, gps0, prm); % With vaccine
      
    #geq = @(t,in) goveqs_scaleup(t, in, M1, M2, tend1b + [0  6], i0, prm, sel0, agg0); 
    #[tc, solnc] = ode15s(geq, [tend1b tend2], initv, opts);
    tc, solnc = ode15s(goveqs_scaleup, initv, create_steps(tend1b, tend2, 1/12), args=(M1, M2, tend1b + np.array([0, 6]), i0, prm, sel0, agg0))
    
    soln  = np.concatenate([solna, solnv[1:,:], solnc[1:,:]]) #soln  = [solna; solnv(2:end,:); solnc(2:end,:)];
    t     = np.concatenate([ta,    tv[1:],      tc[1:]]) #t     = [ta;    tv(2:end);      tc(2:end)];
     
    #soln9 = interp1(t, soln, tref);
    soln9 = np.zeros((len(tref),np.shape(soln)[1])) #soln8 = interp1(t, soln, tref)#soln8 = interp1(t, soln, tref);
    for jj in range(np.shape(soln)[1]):#range(i['nx']):
        temp_fn_sol = interpolate.interp1d(t, soln[:,jj],fill_value="extrapolate") 
        soln9[:,jj] = [temp_fn_sol(ti) for ti in tref]
    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%     
    #% --- Bring them all together (baseline, interventions other than vaccine, interventions including vaccine)
    allmat = np.dstack((soln0, soln8, soln9)) #allmat = cat(3, soln0,soln8,soln9); 
    dallmat = np.diff(allmat,n=1,axis=0) #dallmat = np.diff(allmat,[],1)
    
    inct[:,:] = np.squeeze(dallmat[:,i0['aux']['inc'][0],:])*1e5 #inct(:,:) = squeeze(dallmat(:,i0.aux.inc(1),:))*1e5;    % Total incidence
    inch1[:,:] = np.squeeze(dallmat[:,i0['aux']['inc'][1],:])*1e5 #inch1(:,:) = squeeze(dallmat(:,i0.aux.inc(2),:))*1e5;   % HIV incidence
    mdr[:,:] = np.squeeze(dallmat[:,i0['aux']['inc'][2],:])*1e5 #mdr(:,:) = squeeze(dallmat(:,i0.aux.inc(3),:))*1e5;     % MDR incidence
    morth0[:,:] = np.squeeze(dallmat[:,i0['aux']['mort'][0],:])*1e5 #; % hiv-negative mortality
    morth1[:,:] = np.squeeze(dallmat[:,i0['aux']['mort'](2),:])*1e5 #morth1(:,:) = squeeze(dallmat(:,i0.aux.mort(2),:))*1e5; % hiv-positive mortality
    noti[:,:] = np.squeeze(np.sum(dallmat[:,i0['aux']['noti'],:],1))*1e5 #noti(:,:) = squeeze(sum(dallmat(:,i0.aux.noti,:),2))*1e5; % Total notification
    notimdr[:,:] = np.squeeze(dallmat[:,i0['aux']['noti2'],:])*1e5 #notimdr(:,:) = squeeze(dallmat(:,i0.aux.noti2,:))*1e5;  % MDR Treatment initiation
    
    epi_outputs[0] = inct
    epi_outputs[1] = inch1
    epi_outputs[2] = mdr
    epi_outputs[3] = morth0
    epi_outputs[4] = morth1
    epi_outputs[5] = noti
    epi_outputs[6] = notimdr
    
    
    return(epi_outputs)
    
    
  
#%   prvt = squeeze(sum(allmat(:,s0.prevalent,:),2))*1e5;       % Prevalence
     
#% end
#% fprintf('\n');

#% inc_pct  = permute(prctile(inct,[2.5,50,97.5],3)*1e5,[2,1,3]);
#% hiv_pct  = permute(prctile(inch1,[2.5,50,97.5],3)*1e5,[2,1,3]);
#% mdr_pct  = permute(prctile(mdr,[2.5,50,97.5],3)*1e5,[2,1,3]);
#% mrth0_pct  = permute(prctile(morth0,[2.5,50,97.5],3)*1e5,[2,1,3]);
#% mrth1_pct  = permute(prctile(morth1,[2.5,50,97.5],3)*1e5,[2,1,3]);
#% noti_pct = permute(prctile(noti,[2.5,50,97.5],3)*1e5,[2,1,3]);   
#% notimdr_pct = permute(prctile(notimdr,[2.5,50,97.5],3)*1e5,[2,1,3]);        

#% save res_forward; %with disruption   
#%  
#%  Figure_final
 
#figure; lw = 1.5;
#subplot(2,2,1)
#plot(2022:tend2-1,inct,'linewidth',lw)
#ylabel('All Incidence')
#subplot(2,2,2)
#plot(2022:tend2-1,mdr,'linewidth',lw)
#ylabel('MDR incidence')
#subplot(2,2,3)
#plot(2022:tend2-1,noti,'linewidth',lw)
#ylabel('Notification')
#subplot(2,2,4)
#pl1 = plot(2022:tend2-1,notimdr,'linewidth',lw);
#ylabel('MDR treatment initiation')
#%legend(pl1,'Baseline','+PPM','+ Improved diagnostics, routine TB services','+ Upstream case-finding','+ case-finding among subclinical','+ Preventive therapy (risk group)','+ Upfront DST','+ Shorter duration of 2ndline Tx','+ Improved secondline Tx success','+ Vaccination','location','SouthEast'); %
#legend(pl1,'Baseline','Interventions without vaccine','+ Vaccination','location','SouthEast'); %

#end
 